summaryrefslogtreecommitdiffstats
path: root/test/ttsafe_acreate.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2007-10-04 22:19:07 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2007-10-04 22:19:07 (GMT)
commit1de51c7bc148b9cb5104936dfd23096a222d0cb8 (patch)
treeb23ea23404fd02a41f4539ebbc8311a1c43fecbe /test/ttsafe_acreate.c
parent041de441c5d7468812be8af1346b30db6ea94e3a (diff)
downloadhdf5-1de51c7bc148b9cb5104936dfd23096a222d0cb8.zip
hdf5-1de51c7bc148b9cb5104936dfd23096a222d0cb8.tar.gz
hdf5-1de51c7bc148b9cb5104936dfd23096a222d0cb8.tar.bz2
[svn-r14187] Description:
Put H5Acreate() under API versioning, with all internal usage shifted to H5Acreate2(). Add regression tests for H5Acreate1(). Tested on: FreeBSD/32 6.2 (duty) in debug mode FreeBSD/64 6.2 (liberty) w/C++ & FORTRAN, in debug mode Linux/32 2.6 (kagiso) w/PGI compilers, w/C++ & FORTRAN, w/threadsafe, in debug mode Linux/64-amd64 2.6 (smirom) w/default API=1.6.x, w/C++ & FORTRAN, in production mode Linux/64-ia64 2.6 (cobalt) w/Intel compilers, w/C++ & FORTRAN, in production mode Solaris/32 2.10 (linew) w/deprecated symbols disabled, w/C++ & FORTRAN, w/szip filter, in production mode Mac OS X/32 10.4.10 (amazon) in debug mode
Diffstat (limited to 'test/ttsafe_acreate.c')
-rw-r--r--test/ttsafe_acreate.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/ttsafe_acreate.c b/test/ttsafe_acreate.c
index cfc250b..6409bb1 100644
--- a/test/ttsafe_acreate.c
+++ b/test/ttsafe_acreate.c
@@ -19,17 +19,17 @@
* operations. -- Threaded program --
* ------------------------------------------------------------------
*
* Plan: Attempt to break H5Acreate by making many simultaneous create
* calls.
*
* Claim: N calls to H5Acreate should create N attributes for a dataset
* if threadsafe. If some unprotected shared data exists for the
* dataset (eg, a count of the number of attributes in the
* dataset), there is a small chance that consecutive reads occur
* before a write to that shared variable.
*
* HDF5 APIs exercised in thread:
- * H5Acreate, H5Awrite, H5Aclose.
+ * H5Acreate2, H5Awrite, H5Aclose.
*
* Created: Oct 5 1999
* Programmer: Chee Wai LEE
@@ -167,9 +167,9 @@ void *tts_acreate_thread(void *client_data)
/* Create attribute */
attribute_name = gen_name(attrib_data->current_index);
- attribute = H5Acreate(attrib_data->dataset, attribute_name,
+ attribute = H5Acreate2(attrib_data->dataset, ".", attribute_name,
attrib_data->datatype, attrib_data->dataspace,
- H5P_DEFAULT);
+ H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
/* Write data to the attribute */
attribute_data = malloc(sizeof(int));
@@ -19,17 +19,17 @@
* ------------------------------------------------------------------
*
- * Plan: Attempt to break H5Acreate by making many simultaneous create
+ * Plan: Attempt to break H5Acreate2 by making many simultaneous create
* calls.
*
@@ -19,17 +19,17 @@
* calls.
*
- * Claim: N calls to H5Acreate should create N attributes for a dataset
+ * Claim: N calls to H5Acreate2 should create N attributes for a dataset
* if threadsafe. If some unprotected shared data exists for the
* dataset (eg, a count of the number of attributes in the